/******************************************************************************
 * Double_Command.java - You double.
 * $Id: Double_Command.java,v 1.8 2011/06/11 04:59:04 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Double_Command.java,v $
 * Revision 1.8  2011/06/11 04:59:04  dick
 * [sg]et[po]Die[12] becomes [sg]et[XO]Die[12].
 *
 * Revision 1.7  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.6  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.5  2011/06/05 19:09:42  dick
 * retab.
 *
 * Revision 1.4  2011/06/05 05:59:29  dick
 * mayDouble[12] becomes mayDoube[XO]
 *
 * Revision 1.3  2011/06/04 01:51:51  dick
 * Javadoc.
 *
 * Revision 1.2  2011/05/31 13:02:42  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsQuestion;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.DoubleQuestion;

/** A Player doubles.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.8 $ <br> $Date: 2011/06/11 04:59:04 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Double_Command.java">cvs Double_Command.java</a>
 */
public class Double_Command implements JibsCommand {

	/** Handle the double command.
	 */
	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		JibsGame game = player.getGame();
		String msg = null;
		Object[] obj = null;

		if (game != null) {
			BackgammonBoard board = game.getBackgammonBoard();
			Player playerX = board.getPlayerX();
			Player playerO = board.getPlayerO();

			switch (board.getTurn()) {
			case 1: // O

				if (!board.isCrawFordGame()) {
					int mayDouble = board.getMayDoubleO();

					if (mayDouble == 0) {
						// m_you_double_notallowed=** It's not your turn to
						// double
						msg = jibsMessages.convert("m_you_double_notallowed");
						playerO.println(msg);

						return player.getClientWorker().executeCmd("roll");
					} else {
						if ((board.getODie1().getValue() != 0) &&
								(board.getODie2().getValue() != 0)) {
							// m_you_double_roll=** You can only double before
							// you roll the dice.
							msg = jibsMessages.convert("m_you_double_roll");
							playerO.println(msg);

							return player.getClientWorker().executeCmd("roll");
						}

						// m_you_double=You double. Please wait for %0 to accept
						// or reject.
						obj = new Object[] { playerX.getName() };
						msg = jibsMessages.convert("m_you_double", obj);
						playerO.println(msg);
						// m_opponent_double=%0 doubles. Type 'accept' or
						// 'reject'.
						obj = new Object[] { playerO.getName() };
						msg = jibsMessages.convert("m_opponent_double", obj);
						playerX.println(msg);

						int cubeNumber = board.getCubeNumber() * 2;
						JibsQuestion doubleQuestion = new DoubleQuestion(cubeNumber,
								board.getCubeNumber());
						playerX.ask(doubleQuestion);
					}
				}

				break;

			case -1: // X

				if (!board.isCrawFordGame()) {
					int mayDouble = board.getMayDoubleX();

					if (mayDouble == 0) {
						// m_you_double_notallowed=** It's not your turn to
						// double
						msg = jibsMessages.convert("m_you_double_notallowed");
						playerX.println(msg);

						return player.getClientWorker().executeCmd("roll");
					} else {
						if ((board.getXDie1().getValue() != 0) &&
								(board.getXDie2().getValue() != 0)) {
							// m_you_double_roll=** You can only double before
							// you roll the dice.
							msg = jibsMessages.convert("m_you_double_roll");
							playerX.println(msg);

							return player.getClientWorker().executeCmd("roll");
						}

						// m_you_double=You double. Please wait for %0 to accept
						// or reject.
						obj = new Object[] { playerO.getName() };
						msg = jibsMessages.convert("m_you_double", obj);
						playerX.println(msg);
						// m_opponent_double=%0 doubles. Type 'accept' or
						// 'reject'.
						obj = new Object[] { playerX.getName() };
						msg = jibsMessages.convert("m_opponent_double", obj);
						playerO.println(msg);

						int cubeNumber = board.getCubeNumber() * 2;
						JibsQuestion doubleQuestion = new DoubleQuestion(cubeNumber,
								board.getCubeNumber());
						playerO.ask(doubleQuestion);
					}
				}

				break;
			}
		} else {
			// m_you_not_playing=** You're not playing.
			msg = jibsMessages.convert("m_you_not_playing");
			player.println(msg);
		}

		return true;
	}
}
