/******************************************************************************
 * Resign_Command - Client wants to resign this game
 * $Id: Resign_Command.java,v 1.6 2011/06/09 18:19:18 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Resign_Command.java,v $
 * Revision 1.6  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.5  2011/06/06 03:18:26  dick
 * JibsMessages belongs in n.s.jibs.server, not n.s.jibs.gui
 *
 * Revision 1.4  2011/06/02 19:26:25  dick
 * A backgammon is worth 3 times the cube.
 *
 * Revision 1.3  2011/06/01 20:13:20  dick
 * Watchers get a different resign message (doesn't ask for choice).
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.server.JibsMessages;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.ResignQuestion;

/** Client wants to resign this game
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.6 $ <br> $Date: 2011/06/09 18:19:18 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Resign_Command.java">cvs Resign_Command.java</a>
 */
public class Resign_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		JibsGame game = player.getGame();
		JibsMessages jibsMessages = jibsServer.getJibsMessages();
		int points = 0;
		BackgammonBoard board = game.getBackgammonBoard();

		if ("normal".startsWith(args[1])) {
			points = board.getCubeNumber();
		}

		if ("gammon".startsWith(args[1])) {
			points = 2 * board.getCubeNumber();
		}

		if ("backgammon".startsWith(args[1])) {
			points = 3 * board.getCubeNumber();
		}

		Player opponentPlayer = player.getOpponent();
		Object[] obj = { player.getName(), 
						 opponentPlayer.getName(), 
						 Integer.valueOf(points),
						 points == 1 ? "" : "s"};

		// m_you_resign=You want to resign. %0 will win %1 point%3.
		String msg = jibsMessages.convert("m_you_resign", obj);

		player.println(msg);

//		obj = new Object[] { player.getName(), Integer.valueOf(points) };
		// m_other_resign=%0 wants to resign. You will win %1 point%3. Type 'accept' or 'reject'.
		msg = jibsMessages.convert("m_other_resign", obj);
		opponentPlayer.println(msg);
		
		// m_watcher_resign=%0 wants to resign. %2 will win %1 point%3.
		msg = jibsMessages.convert("m_watcher_resign", obj);

		player.informWatchers(msg, null, false);
		opponentPlayer.informWatchers(msg, null, false);

		opponentPlayer.setQuestion(new ResignQuestion(points));

		return true;
	}
}
