/******************************************************************************
 * JibsUserTableModel.java - The table model for displaying a jIBS Player in a table.
 * $Id: JibsUserTableModel.java,v 1.3 2011/06/02 19:25:27 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: JibsUserTableModel.java,v $
 * Revision 1.3  2011/06/02 19:25:27  dick
 * player.getAdmin() becomes isAdmin().
 *
 * Revision 1.2  2011/05/31 14:50:49  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.gui;

import net.sourceforge.jibs.server.Player;

import java.sql.Date;

import java.util.Vector;

import javax.swing.table.AbstractTableModel;

/** The table model for displaying a jIBS Player in a table.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @since 2004/02/22
 * @version $Revision: 1.3 $ <br> $Date: 2011/06/02 19:25:27 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/gui/JibsUserTableModel.java">cvs JibsUserTableModel.java</a>
 */
public class JibsUserTableModel extends AbstractTableModel {
	private static final long serialVersionUID = 4658136755471549320L;
	private Vector<String> columnIdentifiers = new Vector<String>();
	private Vector<Player> dataVector = new Vector<Player>();

	public JibsUserTableModel() {
		columnIdentifiers.add("Name");
		columnIdentifiers.add("Rating");
		columnIdentifiers.add("Experience");
		columnIdentifiers.add("Password");
		columnIdentifiers.add("E-Mail");
		columnIdentifiers.add("isAdmin");
		columnIdentifiers.add("Last Login Date");
		columnIdentifiers.add("Last Logout Date");
		columnIdentifiers.add("Last Login Host");
	}

	public void deleteUser(Player player) {
		int index = dataVector.indexOf(player);

		if (index >= 0) {
			dataVector.removeElement(player);
			fireTableRowsDeleted(index, index);
		}
	}

	public Class<?> getColumnClass(int columnIndex) {
		switch (columnIndex) {
		case 0: // Name
		case 8: // Last_Login_Host
			return String.class;

		case 1: // Rating
			return Double.class;

		case 2: // Experience
			return Integer.class;

		case 3: // Password
			return String.class;

		case 4: // E-Mail
			return String.class;

		case 5: // isAdmin
			return Boolean.class;

		case 6: // Last_login_date
		case 7: // Last_login_date
			return Date.class;
		}

		return Object.class;
	}

	public String getColumnName(int column) {
		return (String) columnIdentifiers.get(column);
	}

	public Object getValueAt(int row, int column) {
		Player player = (Player) dataVector.get(row);

		switch (column) {
		case 0: // Name
			return player.getName();

		case 1: // Rating
			return Double.valueOf(player.getRating());

		case 2: // Experience
			return Integer.valueOf(player.getExperience());

		case 3: // Password
			return player.getPassword();

		case 4: // E-Mail
			return player.getEmail();

		case 5: // isAdmin
			return Boolean.valueOf(player.isAdmin());

		case 6: // Last_login_date
			return player.getLast_login_date();

		case 7: // Last_logout_date
			return player.getLast_logout_date();

		case 8: // Last_Login_Host
			return player.getLast_login_host();
		}

		return "null";
	}

	public int getColumnCount() {
		return columnIdentifiers.size();
	}

	public int getRowCount() {
		return dataVector.size();
	}

	public boolean isCellEditable(int row, int column) {
		return false;
	}

	public Vector<Player> getDataVector() {
		return dataVector;
	}
}
